searchData={"items":[{"type":"module","title":"Hammer.Backend.Mnesia","doc":"An Mnesia backend for Hammer\n\nThe public API of this module is used by Hammer to store information about\nrate-limit 'buckets'. A bucket is identified by a `key`, which is a tuple\n`{bucket_number, id}`. The essential schema of a bucket is:\n`{key, count, created_at, updated_at}`, although backends are free to\nstore and retrieve this data in whichever way they wish.\n\nUse `start` or `start_link` to start the server:\n\n    {:ok, pid} = Hammer.Backend.Mnesia.start_link(args)\n\n`args` is a keyword list:\n- `expiry_ms`: (integer) time in ms before a bucket is auto-deleted,\n  should be larger than the expected largest size/duration of a bucket\n- `cleanup_interval_ms`: (integer) time between cleanup runs,\n- `table_name`: (atom) table name to use, defaults to `:__hammer_backend_mnesia`,\n\nExample:\n\n    Hammer.Backend.Mnesia.start_link(\n      expiry_ms: 1000 * 60 * 60,\n      cleanup_interval_ms: 1000 * 60 * 10\n    )","ref":"Hammer.Backend.Mnesia.html"},{"type":"function","title":"Hammer.Backend.Mnesia.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hammer.Backend.Mnesia.html#child_spec/1"},{"type":"function","title":"Hammer.Backend.Mnesia.count_hit/3","doc":"Record a hit in the bucket identified by `key`","ref":"Hammer.Backend.Mnesia.html#count_hit/3"},{"type":"function","title":"Hammer.Backend.Mnesia.count_hit/4","doc":"Record a hit in the bucket identified by `key`, with a custom increment","ref":"Hammer.Backend.Mnesia.html#count_hit/4"},{"type":"function","title":"Hammer.Backend.Mnesia.create_mnesia_table/0","doc":"","ref":"Hammer.Backend.Mnesia.html#create_mnesia_table/0"},{"type":"function","title":"Hammer.Backend.Mnesia.create_mnesia_table/1","doc":"","ref":"Hammer.Backend.Mnesia.html#create_mnesia_table/1"},{"type":"function","title":"Hammer.Backend.Mnesia.create_mnesia_table/2","doc":"Create the mnesia table.\n\n- `table_name`: atom name of table, defaults to :__hammer_backend_mnesia\n- `opt`: keyword list of options to `:mnesia.create_table/2`,\nall options are suppoted except\n`:access_mode`, `:attributes`, `:index`, `:type`, and `:record_name`,\nwhich are not configurable.","ref":"Hammer.Backend.Mnesia.html#create_mnesia_table/2"},{"type":"function","title":"Hammer.Backend.Mnesia.delete_buckets/2","doc":"Delete all buckets associated with `id`.","ref":"Hammer.Backend.Mnesia.html#delete_buckets/2"},{"type":"function","title":"Hammer.Backend.Mnesia.get_bucket/2","doc":"Retrieve information about the bucket identified by `key`","ref":"Hammer.Backend.Mnesia.html#get_bucket/2"},{"type":"function","title":"Hammer.Backend.Mnesia.init/1","doc":"","ref":"Hammer.Backend.Mnesia.html#init/1"},{"type":"function","title":"Hammer.Backend.Mnesia.start/0","doc":"","ref":"Hammer.Backend.Mnesia.html#start/0"},{"type":"function","title":"Hammer.Backend.Mnesia.start/1","doc":"","ref":"Hammer.Backend.Mnesia.html#start/1"},{"type":"function","title":"Hammer.Backend.Mnesia.start_link/0","doc":"","ref":"Hammer.Backend.Mnesia.html#start_link/0"},{"type":"function","title":"Hammer.Backend.Mnesia.start_link/1","doc":"","ref":"Hammer.Backend.Mnesia.html#start_link/1"},{"type":"function","title":"Hammer.Backend.Mnesia.stop/0","doc":"","ref":"Hammer.Backend.Mnesia.html#stop/0"},{"type":"type","title":"Hammer.Backend.Mnesia.bucket_info/0","doc":"","ref":"Hammer.Backend.Mnesia.html#t:bucket_info/0"},{"type":"type","title":"Hammer.Backend.Mnesia.bucket_key/0","doc":"","ref":"Hammer.Backend.Mnesia.html#t:bucket_key/0"},{"type":"extras","title":"A Mnesia backend for the Hammer rate-limiter","doc":"# A Mnesia backend for the Hammer rate-limiter\n\n[Hammer](https://github.com/ExHammer/hammer) is a rate-limiter for\nthe [Elixir](https://elixir-lang.org/) language. It's killer feature is a\npluggable backend system, allowing you to use whichever storage suits your\nneeds.\n\nThis package provides a Mnesia backend for Hammer, storing rate-limit counters in an Mnesia table.\n\nTo get started, read\nthe [Hammer Tutorial](https://hexdocs.pm/hammer/tutorial.html) first, then add\nthe `hammer_backend_mnesia` dependency:\n\n```elixir\n    def deps do\n      [{:hammer_backend_mnesia, \"~> 0.6\"},\n      {:hammer, \"~> 6.1\"}]\n    end\n```\n\n... then configure the `:hammer` application to use the Redis backend:\n\n```elixir\nconfig :hammer,\n  backend: {Hammer.Backend.Mnesia, [expiry_ms: 60_000 * 60 * 2,\n                                    cleanup_interval_ms: 60_000 * 15]}\n```\n\nAnd create the Mnesia table for Hammer to use:\n\n```elixir\nHammer.Backend.Mnesia.create_mnesia_table()\n```","ref":"overview.html"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"},{"type":"extras","title":"0.6.1 - 2024-03-29 - CHANGELOG","doc":"#","ref":"changelog.html#0-6-1-2024-03-29"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- loosen dependencies","ref":"changelog.html#changed"},{"type":"extras","title":"0.6.0 - 2024-11-27 - CHANGELOG","doc":"#","ref":"changelog.html#0-6-0-2024-11-27"},{"type":"extras","title":"Changed - CHANGELOG","doc":"- Update Dependencies\n- Clean code\n- Support only for Elixir 1.12 and above","ref":"changelog.html#changed"},{"type":"extras","title":"0.5.0 - 2018-12-31 - CHANGELOG","doc":"Initial release.","ref":"changelog.html#0-5-0-2018-12-31"}],"content_type":"text/markdown"}